#silent install of chrome. installer is the standalone version
#https://dl.google.com/dl/chrome/install/googlechromestandaloneenterprise.msi

from vmcloak.abstract import Dependency

class Chrome(Dependency):
    name = "chrome"
    exes = [
        {
            "url": "http://cuckoo.sh/vmcloak/googlechromestandaloneenterprise.msi",
            "sha1": "5b1fdc38cc8995792c37abcc81f3957d578d2593",
        },
    ]

    def run(self):
        self.upload_dependency("C:\\googlechromestandaloneenterprise.msi")
        self.a.execute("Msiexec /q /I C:\\googlechromestandaloneenterprise.msi")
        self.a.remove("C:\\googlechromestandaloneenterprise.msi")



# Copyright (C) 2014-2015 Jurriaan Bremer.
# This file is part of VMCloak - http://www.vmcloak.org/.
# See the file 'docs/LICENSE.txt' for copying permission.

import time

from vmcloak.abstract import Dependency

class Adobe9(Dependency):
    name = "adobe9"
    exes = [
        {
            "url": "http://cuckoo.sh/vmcloak/AdbeRdr90_en_US.exe",
            "sha1": "8faabd08289b9a88023f71136f13fc4bd3290ef0",
        },
    ]

    def run(self):
        self.upload_dependency("C:\\adobe9.exe")
        self.a.execute("C:\\adobe9.exe", async=True)

        # For some reason clicking buttons for Adobe9 is a bit random
        # sometimes so for now we resort to starting a couple background
        # clicking instances as well.
        self.a.click("Adobe Reader 9 - Setup", "&Next >")

        time.sleep(1)
        self.a.click_async("Adobe Reader 9 - Setup", "&Next >")

        time.sleep(1)
        self.a.click_async("Adobe Reader 9 - Setup", "&Next >")

        self.a.click("Adobe Reader 9 - Setup", "&Install")

        time.sleep(1)
        self.a.click_async("Adobe Reader 9 - Setup", "&Install")

        self.a.click("Adobe Reader 9 - Setup", "&Finish")

        # Wait until adobe9.exe is no longer running.
        self.wait_process_exit("adobe9.exe")

        self.a.remove("C:\\adobe9.exe")



# Copyright (C) 2014-2015 Jurriaan Bremer.
# This file is part of VMCloak - http://www.vmcloak.org/.
# See the file 'docs/LICENSE.txt' for copying permission.

from vmcloak.abstract import Dependency

class DotNet45(Dependency):
    name = "dotnet45"
    depends = "wic",
    url = "http://cuckoo.sh/vmcloak/NDP452-KB2901907-x86-x64-AllOS-ENU.exe"
    sha1 = "89f86f9522dc7a8a965facce839abb790a285a63"

    def run(self):
        # TODO Does not work on Windows XP at the moment.
        self.upload_dependency("C:\\dotnet45.exe")
        self.a.execute("C:\\dotnet45.exe /passive /norestart")
        self.a.remove("C:\\dotnet45.exe")



# Copyright (C) 2014-2015 Jurriaan Bremer.
# This file is part of VMCloak - http://www.vmcloak.org/.
# See the file 'docs/LICENSE.txt' for copying permission.

from vmcloak.abstract import Dependency

class Java7(Dependency):
    name = "java7"
    exes = [
        {
            "url": "http://cuckoo.sh/vmcloak/jdk-7-windows-i586.exe",
            "sha1": "2546a78b6138466b3e23e25b5ca59f1c89c22d03",
        },
    ]

    def run(self):
        self.upload_dependency("C:\\java7.exe")
        self.a.execute("C:\\java7.exe", async=True)
        self.a.click("Java(TM) SE Development Kit 7 - Setup", "&Next >")
        self.a.click("Java(TM) SE Development Kit 7 - Custom Setup", "&Next >")
        self.a.click("Java Setup - Destination Folder", "&Next >")
        self.a.click("Java(TM) SE Development Kit 7 - Complete", "&Finish")

        # Wait until java7.exe & javaw.exe are no longer running.
        self.wait_process_exit("java7.exe")
        self.wait_process_exit("javaw.exe")

        # Wait for iexplore to appear and kill it.
        self.wait_process_appear("iexplore.exe")
        self.a.killprocess("iexplore.exe")

        self.a.remove("C:\\java7.exe")

        if self.i.osversion == "winxp" or self.i.osversion == "win7":
            self.a.execute("reg add \"HKEY_LOCAL_MACHINE\\SOFTWARE\\JavaSoft\\Java Update\\Policy\" /v EnableJavaUpdate /t REG_DWORD /d 0 /f")

        if self.i.osversion == "win7x64":
            self.a.execute("reg add \"HKEY_LOCAL_MACHINE\\SOFTWARE\\Wow6432Node\\JavaSoft\\Java Update\\Policy\" /v EnableJavaUpdate /t REG_DWORD /d 0 /f")



# Copyright (C) 2014-2015 Jurriaan Bremer.
# This file is part of VMCloak - http://www.vmcloak.org/.
# See the file 'docs/LICENSE.txt' for copying permission.

from vmcloak.abstract import Dependency

class InternetExplorer10(Dependency):
    name = "iexplore10"
    exes = [
        {
            "target": "win7x86",
            "sha1": "e6552da75de95f6b1f7937c2bdb5fe14443dea2a",
            "url": "http://cuckoo.sh/vmcloak/IE10-Windows6.1-x86-en-us.exe",
        },
        {
            "target": "win7x64",
            "sha1": "17d1eaca123e453269b12b20863fd5ce96727888",
            "url": "http://cuckoo.sh/vmcloak/IE10-Windows6.1-x64-en-us.exe",
        },
    ]

    def run(self):
        self.upload_dependency("C:\\iexplore10.exe")
        self.a.execute("C:\\iexplore10.exe /passive /update-no")
        self.wait_process_exit("TrustedInstaller.exe")
        self.a.remove("C:\\iexplore10.exe")



# Copyright (C) 2014-2015 Jurriaan Bremer.
# This file is part of VMCloak - http://www.vmcloak.org/.
# See the file 'docs/LICENSE.txt' for copying permission.

from vmcloak.abstract import Dependency

class DotNet40(Dependency):
    name = "dotnet40"
    depends = "wic",
    exes = [
        {
            "url": "http://cuckoo.sh/vmcloak/dotNetFx40_Full_x86_x64.exe",
            "sha1": "58da3d74db353aad03588cbb5cea8234166d8b99",
        },
    ]

    def run(self):
        self.upload_dependency("C:\\dotnet40.exe")
        self.a.execute("C:\\dotnet40.exe /passive /norestart")
        self.a.remove("C:\\dotnet40.exe")



# Silent install of Firefox 41
# https://download-installer.cdn.mozilla.net/pub/firefox/releases/41.0.2/win32/en-US/Firefox%20Setup%2041.0.2.exe
# file was renamed Firefox_Setup_41.0.2.exe to avoid issues with spaces.

from vmcloak.abstract import Dependency

class Firefox_41(Dependency):
    name = "firefox_41"
    exes = [
        {
            "url": "http://cuckoo.sh/vmcloak/Firefox_Setup_41.0.2.exe",
            "sha1": "c5118ca76f0cf6ecda5d2b9292bf191525c9627a",
        },
    ]

    def run(self):
        self.upload_dependency("C:\\Firefox_Setup_41.0.2.exe")
        self.a.execute("C:\\Firefox_Setup_41.0.2.exe -ms")
        self.a.remove("C:\\Firefox_Setup_41.0.2.exe")



# Copyright (C) 2014-2015 Jurriaan Bremer.
# This file is part of VMCloak - http://www.vmcloak.org/.
# See the file 'docs/LICENSE.txt' for copying permission.

import logging
import os.path

from vmcloak.abstract import Dependency

log = logging.getLogger(__name__)

config = """
<Configuration Product="ProPlus">
    <Display Level="none" CompletionNotice="no" SuppressModal="yes" AcceptEula="yes" />
    <PIDKEY Value="%(serial_key)s" />
</Configuration>
"""

class Office2007(Dependency):
    name = "office2007"

    def init(self):
        self.isopath = None
        self.serialkey = None

    def check(self):
        if not self.isopath:
            log.error("Please provide a serial key for Office 2007.")
            return False

        if not os.path.isfile(self.isopath):
            log.error("Please provide the Office 2007 installer ISO file.")
            return False

    def run(self):
        self.disable_autorun()

        self.m.attach_iso(self.isopath)
        self.a.upload("C:\\config.xml", config % dict(serial_key=self.serialkey))
        self.a.execute("D:\\setup.exe /config C:\\config.xml")

        # Wait until setup.exe is no longer running.
        self.wait_process_exit("setup.exe")

        self.a.remove("C:\\config.xml")
        self.m.detach_iso()
